***************
Release History
***************

A new version of sunpy core is released twice a year, with target release months of May and November.
Versions x.0 are long term support (LTS) releases, and are supported for 12 months.
In between versions x.1 are non-LTS releases, and supported for 6 months until the next LTS release.

.. toctree::
   :maxdepth: 1

   changelog
   4.0
   3.1
   3.0
   2.1
   2.0
   1.1
   1.0
   0.9
   0.8
